@@ -12,7 +12,6 @@ from scrapy.core.downloader import Slot
 from twisted.internet import task
 from scrapy.logformatter import LogFormatter
 
-import scrapy_zen.signals
 from scrapy_zen.logging import ScrapyDictFormatter, ZenBufferedLogHandler
 
 
@@ -98,31 +97,32 @@ class ZenStats:
 class ZenBufferedLogs:
 
     def __init__(self, handler: ZenBufferedLogHandler):
-        logging.getLogger().addHandler(handler)
+        root_logger = logging.getLogger()
+        root_logger.addHandler(handler)
         self.handler = handler
 
     @classmethod
     def from_crawler(cls, crawler: Crawler) -> Self:
         if not crawler.settings.getbool("ZEN_BUFFEREDLOGS_ENABLED"):
             raise NotConfigured
-        log_file = crawler.settings.get("LOG_FILE")
+        crawler.settings.update("LOG_ENABLED", False, "addon")
+        log_file = crawler.settings.get("ZEN_BUFFEREDLOGS_LOG_FILE")
         if not log_file:
-            raise NotConfigured
+            raise NotConfigured("ZEN_BUFFEREDLOGS_LOG_FILE not defined")
 
         buffer_length = crawler.settings.getint("ZEN_BUFFEREDLOGS_LENGTH", 50)
         log_format = crawler.settings.get('LOG_FORMAT', '%(asctime)s [%(name)s] %(levelname)s: %(message)s')
         log_dateformat = crawler.settings.get('LOG_DATEFORMAT', '%Y-%m-%d %H:%M:%S')
         formatter = ScrapyDictFormatter(fmt=log_format, datefmt=log_dateformat)
-        filename = pathlib.Path(log_file).stem + "_buffered.log"
-        handler = ZenBufferedLogHandler(filename, buffer_length)
+        handler = ZenBufferedLogHandler(log_file, buffer_length)
         handler.setFormatter(formatter)
 
         ext = cls(handler)
 
-        crawler.signals.connect(ext.new_item, signal=scrapy_zen.signals.new_item)
+        crawler.signals.connect(ext.item_scraped, signal=signals.item_scraped)
         return ext
 
-    def new_item(self, item: Dict, spider: Spider):
+    def item_scraped(self, item: Dict, spider: Spider):
         self.handler.flush()
 
 
