@@ -17,8 +17,6 @@ from scrapy import Item, signals
 import websockets
 import logging
 
-import scrapy_zen.signals
-
 logging.getLogger("websockets").setLevel(logging.WARNING)
 logging.getLogger("pymongo").setLevel(logging.ERROR)
 
@@ -177,11 +175,6 @@ class PreProcessingPipeline(ItemValidationPipeline):
         if self.settings.get("LOG_LEVEL","") == "INFO":
             spider.logger.info(item)
 
-        spider.crawler.signals.send_catch_log(
-            signal=scrapy_zen.signals.new_item,
-            item=item,
-            spider=spider
-        )
         return item
 
 
